﻿namespace StockSharp.Plaza.Metadata
{
    /// <summary>
    /// Поток FORTS_INFO_REPL - Дополнительная справочная информация.
    /// Таблица base_contracts_params - Параметры базовых контрактов.
    /// </summary>
    public class PlazaBaseContractsParamsColumns : PlazaColumns
    {
        internal PlazaBaseContractsParamsColumns()
            : base(PlazaTableId.BaseContractsParams)
        {
            CodeVCB = new PlazaColumn(TableId, "code_vcb", "c25");
            CodeMCS = new PlazaColumn(TableId, "code_mcs", "c25");
            VolatNum = new PlazaColumn(TableId, "volat_num", typeof(byte));
            PointsNum = new PlazaColumn(TableId, "points_num", typeof(byte));
            SubRiskStep = new PlazaColumn(TableId, "subrisk_step", typeof(double));
            IsPercent = new PlazaColumn(TableId, "is_percent", typeof(byte));
            PercentRate = new PlazaColumn(TableId, "percent_rate", "d16.5");
            CurrencyVolat = new PlazaColumn(TableId, "currency_volat", "d16.5");
            IsUsd = new PlazaColumn(TableId, "is_usd", typeof(byte));
            UsdRateCurvRadius = new PlazaColumn(TableId, "usd_rate_curv_radius", typeof(double));
            Somc = new PlazaColumn(TableId, "somc", typeof(double));
        }

        /// <summary>
        /// Код базового контракта.
        /// </summary>
        public readonly PlazaColumn CodeVCB;

        /// <summary>
        /// Код межконтрактного спрэда.
        /// </summary>
        public readonly PlazaColumn CodeMCS;

        /// <summary>
        /// Количество кривых волатильности.
        /// </summary>
        public readonly PlazaColumn VolatNum;

        /// <summary>
        /// Количество точек риска.
        /// </summary>
        public readonly PlazaColumn PointsNum;

        /// <summary>
        /// Шаг подточек риска.
        /// </summary>
        public readonly PlazaColumn SubRiskStep;

        /// <summary>
        /// Признак процентного контракта.
        /// </summary>
        public readonly PlazaColumn IsPercent;

        /// <summary>
        /// Процентная ставка (для контрактов на ставки).
        /// </summary>
        public readonly PlazaColumn PercentRate;

        /// <summary>
        /// Волатильность курса валюты.
        /// </summary>
        public readonly PlazaColumn CurrencyVolat;

        /// <summary>
        /// Признак расчета в долларах.
        /// </summary>
        public readonly PlazaColumn IsUsd;

        /// <summary>
        /// Радиус кривизны курса валюты.
        /// </summary>
        public readonly PlazaColumn UsdRateCurvRadius;

        /// <summary>
        /// Ставка ГО по непокрытым продажам (в рублях).
        /// </summary>
        public readonly PlazaColumn Somc;

    }
}
