﻿namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Поток FORTS_CLR_REPL - Деньги в клиринг.
    /// Таблица money_clearing - Клиентские деньги в клиринге.
	/// </summary>
	public class PlazaClearingMoneyColumns : PlazaColumns
	{
        internal PlazaClearingMoneyColumns()
			: base(PlazaTableId.ClearingMoney)
		{
            ClientCode = new PlazaColumn(TableId, "client_code", "c7");
            Share = new PlazaColumn(TableId, "share", typeof(byte));
            BegAmount = new PlazaColumn(TableId, "amount_beg", "d16.2");
            VM = new PlazaColumn(TableId, "vm", "d16.2");
            Premium = new PlazaColumn(TableId, "premium", "d16.2");
            Pay = new PlazaColumn(TableId, "pay", "d16.2");
            FutFee = new PlazaColumn(TableId, "fee_fut", "d16.2");
            OptFee = new PlazaColumn(TableId, "fee_opt", "d16.2");
            GO = new PlazaColumn(TableId, "go", "d16.2");
            EndAmount = new PlazaColumn(TableId, "amount_end", "d21.2");
            Free = new PlazaColumn(TableId, "free", "d22.2");
		}

		/// <summary>
        /// Код клиента.
		/// </summary>
		public readonly PlazaColumn ClientCode;

		/// <summary>
        /// Тип счета.
		/// </summary>
        public readonly PlazaColumn Share;

		/// <summary>
        /// Денег на начало дня.
		/// </summary>
        public readonly PlazaColumn BegAmount;

		/// <summary>
		/// Вариационная маржа, включая вариационную маржу по маржируемым опционам.
		/// </summary>
		public readonly PlazaColumn VM;

		/// <summary>
        /// Опционная премия.
		/// </summary>
        public readonly PlazaColumn Premium;

		/// <summary>
        /// Движение по счету.
		/// </summary>
		public readonly PlazaColumn Pay;

		/// <summary>
        /// Фьючерсный биржевой сбор.
		/// </summary>
		public readonly PlazaColumn FutFee;

        /// <summary>
        /// Опционный биржевой сбор.
        /// </summary>
        public readonly PlazaColumn OptFee;

        /// <summary>
        /// Суммарное ГО по фьючерсам и опционам.
        /// </summary>
        public readonly PlazaColumn GO;

        /// <summary>
        /// На конец дня.
        /// </summary>
        public readonly PlazaColumn EndAmount;
        
        /// <summary>
        /// Свободно средств.
        /// </summary>
        public readonly PlazaColumn Free;

	}
}
