﻿namespace StockSharp.Plaza.Metadata
{
	using System;

	using Ecng.Common;
	using Ecng.Serialization;

	/// <summary>
	/// Колонка таблицы с метаданными.
	/// </summary>
	[EntityFactory(typeof(UnitializedEntityFactory<PlazaColumn>))]
	[TypeSchemaFactory(SearchBy.Properties, VisibleScopes.Both)]
	[Ignore(FieldName = "IsDisposed")]
	public class PlazaColumn : Equatable<PlazaColumn>
	{
		private readonly int _hashCode;

		internal PlazaColumn(PlazaTableId tableId, string name, PlazaType plazaType, bool isMandatory = true)
		{
			if (tableId == null)
				throw new ArgumentNullException("tableId");

			if (name.IsEmpty())
				throw new ArgumentNullException("name");

			TableId = tableId;
			IsMandatory = isMandatory;
			Name = name;
			PlazaType = plazaType;

			_hashCode = TableId.GetHashCode() ^ Name.GetHashCode();
		}
		
		internal bool IsMandatory { get; private set; }

		//internal int Index { get; set; }

		internal PlazaTableId TableId { get; private set; }

		/// <summary>
		/// Название колонки.
		/// </summary>
		public string Name { get; private set; }

		/// <summary>
		/// Тип колонки (Plaza).
		/// </summary>
		public PlazaType PlazaType { get; private set; }

		/// <summary>
		/// Создать копию объекта <see cref="PlazaColumn"/>.
		/// </summary>
		/// <returns>Копия.</returns>
		public override PlazaColumn Clone()
		{
			return new PlazaColumn(TableId, Name, PlazaType, IsMandatory);
		}

		/// <summary>
		/// Сравнить две колонки на эквивалентность.
		/// </summary>
		/// <param name="other">Другая колонка, с которой необходимо сравнивать.</param>
		/// <returns>true, если другая колонка равна текущей, иначе false.</returns>
		protected override bool OnEquals(PlazaColumn other)
		{
			return ReferenceEquals(this, other);
		}

		/// <summary>
		/// Рассчитать хеш-код колонки.
		/// </summary>
		/// <returns>Хеш-код колонки.</returns>
		public override int GetHashCode()
		{
			return _hashCode;
		}

		/// <summary>
		/// Получить строковое представление.
		/// </summary>
		/// <returns>Строковое представление.</returns>
		public override string ToString()
		{
			return Name;
		}
	}
}