﻿namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Реестр всех колонок, описывающие метаданные Plaza.
	/// </summary>
	public static class PlazaColumnRegistry
	{
		#region Стаканы

		/// <summary>
		/// Колонки стакана глубиной 50 котировок.
		/// </summary>
		public static readonly PlazaAggregationColumns Aggregation50Future = new PlazaAggregationColumns(PlazaTableId.Aggregation50Future);

		/// <summary>
		/// Колонки стакана глубиной 20 котировок.
		/// </summary>
		public static readonly PlazaAggregationColumns Aggregation20Future = new PlazaAggregationColumns(PlazaTableId.Aggregation20Future);

		/// <summary>
		/// Колонки стакана глубиной 5 котировок.
		/// </summary>
		public static readonly PlazaAggregationColumns Aggregation5Future = new PlazaAggregationColumns(PlazaTableId.Aggregation5Future);

		/// <summary>
		/// Колонки стакана глубиной 50 котировок.
		/// </summary>
		public static readonly PlazaAggregationColumns Aggregation50Option = new PlazaAggregationColumns(PlazaTableId.Aggregation50Option);

		/// <summary>
		/// Колонки стакана глубиной 20 котировок.
		/// </summary>
		public static readonly PlazaAggregationColumns Aggregation20Option = new PlazaAggregationColumns(PlazaTableId.Aggregation20Option);

		/// <summary>
		/// Колонки стакана глубиной 5 котировок.
		/// </summary>
		public static readonly PlazaAggregationColumns Aggregation5Option = new PlazaAggregationColumns(PlazaTableId.Aggregation5Option);

		#endregion // Стаканы

		#region Bond

		/// <summary>
		/// Колонки справочника инструментов облигаций.
		/// </summary>
		public static readonly PlazaBondIsinFutureColumns BondIsinFuture = new PlazaBondIsinFutureColumns();

		/// <summary>
		/// Колонки таблицы НКД на даты выплат купонов.
		/// </summary>
		public static readonly PlazaBondNkdFutureColumns BondNkdFuture = new PlazaBondNkdFutureColumns();

		/// <summary>
		/// Колонки таблицы размеров выплат номинальной стоимости облигации.
		/// </summary>
		public static readonly PlazaBondNominalFutureColumns BondNominalFuture = new PlazaBondNominalFutureColumns();

		/// <summary>
		/// Колонки справочника параметров облигаций.
		/// </summary>
		public static readonly PlazaBondRegistryFutureColumns BondRegistryFuture = new PlazaBondRegistryFutureColumns();

		#endregion

		#region Common

		/// <summary>
		/// Колонки справочника базовых контрактов для инструментов.
		/// </summary>
		public static readonly PlazaCommonOptionColumns CommonOption = new PlazaCommonOptionColumns();

		/// <summary>
		/// Колонки справочника базовых контрактов для инструментов.
		/// </summary>
		public static readonly PlazaCommonFutureColumns CommonFuture = new PlazaCommonFutureColumns();

		#endregion

		#region Deal

		/// <summary>
		/// Колонки журнала сделок.
		/// </summary>
		public static readonly PlazaDealOptionColumns DealOption = new PlazaDealOptionColumns();

		/// <summary>
		/// Колонки журнала сделок.
		/// </summary>
		public static readonly PlazaDealFutureColumns DealFuture = new PlazaDealFutureColumns();

		#endregion

		/// <summary>
		/// Колонки отчетов о поставке.
		/// </summary>
		public static readonly PlazaDeliveryReportFutureColumns DeliveryReportFuture = new PlazaDeliveryReportFutureColumns();

		/// <summary>
		/// Колонки заявок на экспирацию.
		/// </summary>
		public static readonly PlazaExpirationOrdersOptionColumns ExpirationOrdersOption = new PlazaExpirationOrdersOptionColumns();

		#region HeartBeat

		/// <summary>
		/// Колонки служебной таблицы cерверных часов.
		/// </summary>
		public static readonly PlazaHeartBeatColumns HeartBeatFuture = new PlazaHeartBeatColumns(PlazaTableId.HeartBeatFuture);

		/// <summary>
		/// Колонки служебной таблицы cерверных часов.
		/// </summary>
		public static readonly PlazaHeartBeatColumns HeartBeatOption = new PlazaHeartBeatColumns(PlazaTableId.HeartBeatOption);

		#endregion

		/// <summary>
		/// Колонки таблицы индексов.
		/// </summary>
		public static readonly PlazaIndexColumns RtsIndex = new PlazaIndexColumns();

        /// <summary>
        /// Колонки таблицы с историей значений индексов.
        /// </summary>
        public static readonly PlazaIndexLogColumns RtsIndexLog = new PlazaIndexLogColumns();

		#region InterClearingInfo

		/// <summary>
		/// Колонки таблицы с информацией о ВМ, рассчитанной по результатам пром. клиринга.
		/// </summary>
		public static readonly PlazaInterClearingInfoFutureColumns InterClearingInfoFuture = new PlazaInterClearingInfoFutureColumns();

		/// <summary>
		/// Колонки таблицы с информацией о ВМ, рассчитанной по результатам пром. клиринга.
		/// </summary>
		public static readonly PlazaInterClearingInfoOptionColumns InterClearingInfoOption = new PlazaInterClearingInfoOptionColumns();

		#endregion

		/// <summary>
		/// Колонки журнала заявок по связкам.
		/// </summary>
		public static readonly PlazaMultiLegOrdersLogFutureColumns MultiLegOrdersLogFuture = new PlazaMultiLegOrdersLogFutureColumns();

		/// <summary>
		/// Колонки журнала сделок по связкам.
		/// </summary>
		public static readonly PlazaMultiLegDealFutureColumns MultiLegDealFuture = new PlazaMultiLegDealFutureColumns();

		#region OrderBookInfo

		/// <summary>
		/// Колонки таблицы с информацией о стаканах.
		/// </summary>
		public static readonly PlazaOrderBookInfoFutureColumns OrderBookInfoFuture = new PlazaOrderBookInfoFutureColumns();

		/// <summary>
		/// Колонки таблицы с информацией о стаканах.
		/// </summary>
		public static readonly PlazaOrderBookInfoOptionColumns OrderBookInfoOption = new PlazaOrderBookInfoOptionColumns();

		#endregion

		#region OrderBookOrders

		/// <summary>
		/// Колонки таблицы логов заявок.
		/// </summary>
		public static readonly PlazaOrderBookOrdersFutureColumns OrderBookOrdersFuture = new PlazaOrderBookOrdersFutureColumns();

		/// <summary>
		/// Колонки таблицы логов заявок.
		/// </summary>
		public static readonly PlazaOrderBookOrdersOptionColumns OrderBookOrdersOption = new PlazaOrderBookOrdersOptionColumns();

		#endregion

		#region OrdersLog

		/// <summary>
		/// Колонки журнала заявок по связкам.
		/// </summary>
		public static readonly PlazaOrdersLogFutureColumns OrdersLogFuture = new PlazaOrdersLogFutureColumns();

		/// <summary>
		/// Колонки журнала заявок по связкам.
		/// </summary>
		public static readonly PlazaOrdersLogOptionColumns OrdersLogOption = new PlazaOrdersLogOptionColumns();

		#endregion

		/// <summary>
		/// Колонки таблицы позиций клиентов.
		/// </summary>
		public static readonly PlazaPositionColumns Positions = new PlazaPositionColumns();

		/// <summary>
		/// Колонки таблицы средств и лимитов клиентов.
		/// </summary>
		public static readonly PlazaPortfolioColumns Portfolios = new PlazaPortfolioColumns();

		#region RejectedOrders

		/// <summary>
		/// Колонки таблицы отвергнутых в клиринг заявок.
		/// </summary>
		public static readonly PlazaRejectedOrdersFutureColumns RejectedOrdersFuture = new PlazaRejectedOrdersFutureColumns();

		/// <summary>
		/// Колонки таблицы отвергнутых в клиринг заявок.
		/// </summary>
		public static readonly PlazaRejectedOrdersOptionColumns RejectedOrdersOption = new PlazaRejectedOrdersOptionColumns();

		#endregion

		#region SessionContents

		/// <summary>
		/// Колонки справочника торгуемых инструментов.
		/// </summary>
		public static readonly PlazaSessionContentsFutureColumns SessionContentsFuture = new PlazaSessionContentsFutureColumns();

		/// <summary>
		/// Колонки справочника торгуемых инструментов.
		/// </summary>
		public static readonly PlazaSessionContentsOptionColumns SessionContentsOption = new PlazaSessionContentsOptionColumns();

		#endregion

		/// <summary>
		/// Колонки таблицы с информацией о торговой сессии.
		/// </summary>
		public static readonly PlazaSessionFutureColumns SessionFuture = new PlazaSessionFutureColumns();

        /// <summary>
        /// Колонки таблицы с cообщениями торговой системы.
        /// </summary>
        public static readonly PlazaSysMessagesColumns SysMessages = new PlazaSysMessagesColumns();

		/// <summary>
		/// Колонки таблицы с результатами клиринга: волатильность и теоретические цены.
		/// </summary>
		public static readonly PlazaSessionSettlementOptionColumns SessionSettlementOption = new PlazaSessionSettlementOptionColumns();

        /// <summary>
        /// Колонки таблицы с результатами клиринга: расчетные цены.
        /// </summary>
        public static readonly PlazaSessionSettlementFutureColumns SessionSettlementFuture = new PlazaSessionSettlementFutureColumns();

		/// <summary>
		/// Колонки таблицы с трансляцией курса USD.
		/// </summary>
		public static readonly PlazaUsdOnlineColumns UsdOnline = new PlazaUsdOnlineColumns();

        /// <summary>
        /// Колонки таблицы с именами фирм.
        /// </summary>
        public static readonly PlazaDilerColumns Diler = new PlazaDilerColumns();

        /// <summary>
        /// Колонки таблицы с клиентами.
        /// </summary>
		public static readonly PlazaInvestorColumns Investor = new PlazaInvestorColumns();
        /*
        /// <summary>
        /// Колонки таблицы с инструментами.
        /// </summary>
        public static readonly PlazaFutInstrumentsColumns FutInstruments = new PlazaFutInstrumentsColumns();
        */
		#region Vcb

		/// <summary>
		/// Колонки справочника базовых контрактов для фьючерсов.
		/// </summary>
		public static readonly PlazaVcbFutureColumns VcbFuture = new PlazaVcbFutureColumns();

		/// <summary>
		/// Колонки справочника базовых контрактов для опционов.
		/// </summary>
		public static readonly PlazaVcbOptionColumns VcbOption = new PlazaVcbOptionColumns();

		#endregion

		#region Вариационная маржа

		/// <summary>
		/// Колонки таблицы с вариационной маржой по фьючерсам.
		/// </summary>
		public static readonly PlazaVmFutureColumns VmFuture = new PlazaVmFutureColumns();

		/// <summary>
		/// Колонки таблицы с вариационной маржой по опционам.
		/// </summary>
		public static readonly PlazaVmOptionColumns VmOption = new PlazaVmOptionColumns();

		#endregion // Вариационная маржа

		/// <summary>
		/// Колонки таблицы с коэффициентами волатильности.
		/// </summary>
		public static readonly PlazaVolatilitySmileColumns VolatilitySmile = new PlazaVolatilitySmileColumns();

		/// <summary>
		/// Колонки таблицы с волатильностью.
		/// </summary>
		public static readonly PlazaVolatilityColumns Volatility = new PlazaVolatilityColumns();

        /// <summary>
        /// Колонки таблицы с клиентскими деньгами в клиринг.
        /// </summary>
        public static readonly PlazaClearingMoneyColumns ClearingMoney = new PlazaClearingMoneyColumns();

        #region Дополнительная справочная информация

        /// <summary>
        /// Колонки таблицы с параметрами базовых контрактов.
        /// </summary>
        public static readonly PlazaBaseContractsParamsColumns BaseContractsParams = new PlazaBaseContractsParamsColumns();

        /// <summary>
        /// Колонки таблицы с параметрами фьючерсов.
        /// </summary>
        public static readonly PlazaFuturesParamsColumns FuturesParams = new PlazaFuturesParamsColumns();

        /// <summary>
        /// Колонки таблицы с параметрами виртуальных фьючерсов.
        /// </summary>
        public static readonly PlazaVirtualFuturesParamsColumns VirtualFuturesParams = new PlazaVirtualFuturesParamsColumns();

        /// <summary>
        /// Колонки таблицы с параметрами опционов.
        /// </summary>
        public static readonly PlazaOptionsParamsColumns OptionsParams = new PlazaOptionsParamsColumns();

        /// <summary>
        /// Колонки таблицы с информацией о параметрах фирм.
        /// </summary>
        public static readonly PlazaBrokerParamsColumns BrokerParams = new PlazaBrokerParamsColumns();

        /// <summary>
        /// Колонки таблицы с информацией о параметрах клиентов.
        /// </summary>
        public static readonly PlazaClientParamsColumns ClientParams = new PlazaClientParamsColumns();



        #endregion
    }
}
