﻿namespace StockSharp.Plaza.Metadata
{
	using System;

	/// <summary>
	/// Поток FORTS_OPTINFO_REPL - Опционы: справочная и сессионная информация.
	/// Таблица opt_exp_orders: Заявки на экспирацию.
	/// </summary>
	public class PlazaExpirationOrdersOptionColumns : PlazaColumns
	{
		internal PlazaExpirationOrdersOptionColumns()
			: base(PlazaTableId.ExpirationOrdersOption)
		{
			OrderId = new PlazaColumn(TableId, "exporder_id", typeof(long));
			ClientCode = new PlazaColumn(TableId, "client_code", "c7");
			IsinId = new PlazaColumn(TableId, "isin_id", typeof(int));
			Amount = new PlazaColumn(TableId, "amount", typeof(int));
			SessionId = new PlazaColumn(TableId, "sess_id", typeof(int));
			Date = new PlazaColumn(TableId, "date", typeof(DateTime));
			AmountApply = new PlazaColumn(TableId, "amount_apply", typeof(int));
		}

		/// <summary>
		/// Идентификатор заявки на экспирацию.
		/// </summary>
		public readonly PlazaColumn OrderId;

		/// <summary>
		/// Уникальный числовой идентификатор инструмента.
		/// </summary>
		public readonly PlazaColumn IsinId;

		/// <summary>
		/// Код клиента.
		/// </summary>
		public readonly PlazaColumn ClientCode;

		/// <summary>
		/// Количество экспирируемых позиций.
		/// </summary>
		public readonly PlazaColumn Amount;

		/// <summary>
		/// Идентификатор торговой сессии.
		/// </summary>
		public readonly PlazaColumn SessionId;

		/// <summary>
		/// Дата и время.
		/// </summary>
		public readonly PlazaColumn Date;

		/// <summary>
		/// Кол-во в заявках на момент пром.клиринга.
		/// </summary>
		public readonly PlazaColumn AmountApply;
	}
}