﻿namespace StockSharp.Plaza.Metadata
{
	using System;

	/// <summary>
	/// FORTS_FUTTRADE_REPL - Фьючерсы: заявки и сделки.
	/// Таблица multileg_deal: Журнал сделок по связкам.
	/// </summary>
	public class PlazaMultiLegDealFutureColumns : PlazaColumns
	{
		internal PlazaMultiLegDealFutureColumns()
			: base(PlazaTableId.MultiLegDealFuture)
		{
			DealId = new PlazaColumn(TableId, "id_deal", typeof(long));
			SessionId = new PlazaColumn(TableId, "sess_id", typeof(int));
			IsinId = new PlazaColumn(TableId, "isin_id", typeof(int));
			Price = new PlazaColumn(TableId, "price", "d16.5");
			Amount = new PlazaColumn(TableId, "amount", typeof(int));
			Moment = new PlazaColumn(TableId, "moment", typeof(DateTime));
			SellCode = new PlazaColumn(TableId, "code_sell", "c7");
			BuyCode = new PlazaColumn(TableId, "code_buy", "c7");
			SellOrderId = new PlazaColumn(TableId, "id_ord_sell", typeof(long));
			SellExternalId = new PlazaColumn(TableId, "ext_id_sell", typeof(int));
			SellComment = new PlazaColumn(TableId, "comment_sell", "c20");
			SellTrust = new PlazaColumn(TableId, "trust_sell", typeof(bool));
			SellStatus = new PlazaColumn(TableId, "status_sell", typeof(int));
			BuyOrderId = new PlazaColumn(TableId, "id_ord_buy", typeof(long));
			BuyExternalId = new PlazaColumn(TableId, "ext_id_buy", typeof(int));
			BuyComment = new PlazaColumn(TableId, "comment_buy", "c20");
			BuyTrust = new PlazaColumn(TableId, "trust_buy", typeof(bool));
			BuyStatus = new PlazaColumn(TableId, "status_buy", typeof(int));
			NoSystem = new PlazaColumn(TableId, "nosystem", typeof(bool));
			RatePrice = new PlazaColumn(TableId, "rate_price", "d16.5");
			SwapPrice = new PlazaColumn(TableId, "swap_price", "d16.5");
			HedgeSell = new PlazaColumn(TableId, "hedge_sell", typeof(bool));
			HedgeBuy = new PlazaColumn(TableId, "hedge_buy", typeof(bool));
			SellCodeRts = new PlazaColumn(TableId, "code_rts_sell", "c7");
			BuyCodeRts = new PlazaColumn(TableId, "code_rts_buy", "c7");
		}

		/// <summary>
		/// Номер сделки.
		/// </summary>
		public readonly PlazaColumn DealId;

		/// <summary>
		/// Идентификатор торговой сессии.
		/// </summary>
		public readonly PlazaColumn SessionId;

		/// <summary>
		/// Уникальный числовой идентификатор инструмента.
		/// </summary>
		public readonly PlazaColumn IsinId;

		/// <summary>
		/// Цена.
		/// </summary>
		public readonly PlazaColumn Price;

		/// <summary>
		/// Количество в операции.
		/// </summary>
		public readonly PlazaColumn Amount;

		/// <summary>
		/// Время изменения состояния заявки.
		/// </summary>
		public readonly PlazaColumn Moment;

		/// <summary>
		/// Код продавца. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn SellCode;

		/// <summary>
		/// Код покупателя. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn BuyCode;

		/// <summary>
		/// Номер заявки продавца.
		/// </summary>
		public readonly PlazaColumn SellOrderId;

		/// <summary>
		/// Внешний номер из заявки продавца. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn SellExternalId;

		/// <summary>
		/// Комментарий из заявки продавца.	Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn SellComment;

		/// <summary>
		/// Признак ДУ (доверительного управления) из заявки продавца. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn SellTrust;

		/// <summary>
		/// Статус сделки со стороны продавца.
		/// </summary>
		public readonly PlazaColumn SellStatus;

		/// <summary>
		/// Номер заявки покупателя.
		/// </summary>
		public readonly PlazaColumn BuyOrderId;

		/// <summary>
		/// Внешний номер из заявки покупателя.	Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn BuyExternalId;

		/// <summary>
		/// Комментарий из заявки покупателя. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn BuyComment;

		/// <summary>
		/// Признак ДУ (доверительного управления) из заявки покупателя. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn BuyTrust;

		/// <summary>
		/// Статус сделки со стороны продавца.
		/// </summary>
		public readonly PlazaColumn BuyStatus;

		/// <summary>
		/// Признак внесистемной сделки.
		/// </summary>
		public readonly PlazaColumn NoSystem;

		/// <summary>
		/// Ставка заявки. Поле rate_price для валютных свопов содержит своп-цену.
		/// </summary>
		public readonly PlazaColumn RatePrice;

		/// <summary>
		/// Своп-цена заявки.
		/// </summary>
		public readonly PlazaColumn SwapPrice;

		/// <summary>
		/// Признак хеджевой сделки со стороны продавца. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn HedgeSell;

		/// <summary>
		/// Признак хеджевой сделки со стороны покупателя. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn HedgeBuy;

		/// <summary>
		/// Код РТС продавца. Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn SellCodeRts;

		/// <summary>
		/// Код РТС покупателя.	Заполнено только для своих сделок.
		/// </summary>
		public readonly PlazaColumn BuyCodeRts;
	}
}