﻿namespace StockSharp.Plaza.Metadata
{
    /// <summary>
    /// Поток FORTS_INFO_REPL - Дополнительная справочная информация.
    /// Таблица options_params - Параметры опционов.
    /// </summary>
    public class PlazaOptionsParamsColumns : PlazaColumns
    {
        internal PlazaOptionsParamsColumns()
            : base(PlazaTableId.OptionsParams)
        {
            Isin = new PlazaColumn(TableId, "isin", "c25");
            IsinId = new PlazaColumn(TableId, "isin_id", typeof(int));
            IsinBase = new PlazaColumn(TableId, "isin_base", "c25");
            Strike = new PlazaColumn(TableId, "strike", "d16.5");
            OptType = new PlazaColumn(TableId, "opt_type", typeof(byte));
            SettlPrice = new PlazaColumn(TableId, "settl_price", "d16.5");
            BaseGOSell = new PlazaColumn(TableId, "base_go_sell", "d26.2");
            SynthBaseGO = new PlazaColumn(TableId, "synth_base_go", "d26.2");
            BaseGOBuy = new PlazaColumn(TableId, "base_go_buy", "d26.2");
        }

        /// <summary>
        /// Идентификатор инструмента.
        /// </summary>
        public readonly PlazaColumn Isin;

        /// <summary>
        /// Уникальный числовой идентификатор инструмента.
        /// </summary>
        public readonly PlazaColumn IsinId;
        
        /// <summary>
        /// Код виртуального фьючерса.
        /// </summary>
        public readonly PlazaColumn IsinBase;

        /// <summary>
        /// Страйк опциона.
        /// </summary>
        public readonly PlazaColumn Strike;

        /// <summary>
        /// Тип опциона: 1 - PUT, 2 - CALL.
        /// </summary>
        public readonly PlazaColumn OptType;

        /// <summary>
        /// Расчетная цена.
        /// </summary>
        public readonly PlazaColumn SettlPrice;

        /// <summary>
        /// Базовое ГО на продажу.
        /// </summary>
        public readonly PlazaColumn BaseGOSell;

        /// <summary>
        /// Базовое ГО по синтетической позиции на продажу.
        /// </summary>
        public readonly PlazaColumn SynthBaseGO;

        /// <summary>
        /// Базовое ГО на покупку.
        /// </summary>
        public readonly PlazaColumn BaseGOBuy;

    }
}