﻿namespace StockSharp.Plaza.Metadata
{
	using System;

	/// <summary>
	/// Колонки таблицы, содержащей торгуемые инструменты.
	/// </summary>
	public abstract class PlazaSessionContentsDerivativeColumns : PlazaColumns
	{
		internal PlazaSessionContentsDerivativeColumns(PlazaTableId tableId)
			: base(tableId)
		{
			SessionId = new PlazaColumn(TableId, "sess_id", typeof(int));
			IsinId = new PlazaColumn(TableId, "isin_id", typeof(int));
			ShortIsin = new PlazaColumn(TableId, "short_isin", "c25");
			Isin = new PlazaColumn(TableId, "isin", "c25");
			Name = new PlazaColumn(TableId, "name", "c75");
			CodeVcb = new PlazaColumn(TableId, "code_vcb", "c25");
			IsLimited = new PlazaColumn(TableId, "is_limited", typeof(bool));
			LimitUp = new PlazaColumn(TableId, "limit_up", "d16.5");
			LimitDown = new PlazaColumn(TableId, "limit_down", "d16.5");
			OldKotir = new PlazaColumn(TableId, "old_kotir", "d16.5");
			MinStep = new PlazaColumn(TableId, "min_step", "d16.5");
			LotVolume = new PlazaColumn(TableId, "lot_volume", typeof(int));
			StepPrice = new PlazaColumn(TableId, "step_price", "d16.5");
			DateEndTrade = new PlazaColumn(TableId, "d_pg", typeof(DateTime));
			LastClearingQuote = new PlazaColumn(TableId, "last_cl_quote", "d16.5");
			Signs = new PlazaColumn(TableId, "signs", typeof(int));
			RoundTo = new PlazaColumn(TableId, "roundto", typeof(int));
		}

		/// <summary>
		/// Идентификатор торговой сессии.
		/// </summary>
		public readonly PlazaColumn SessionId;

		/// <summary>
		/// Уникальный числовой идентификатор инструмента.
		/// </summary>
		public readonly PlazaColumn IsinId;

		/// <summary>
		/// Описатель инструмента.
		/// </summary>
		public readonly PlazaColumn ShortIsin;

		/// <summary>
		/// Символьный код инструмента.
		/// </summary>
		public readonly PlazaColumn Isin;

		/// <summary>
		/// Наименование инструмента.
		/// </summary>
		public readonly PlazaColumn Name;

		/// <summary>
		/// Признак наличия лимитов в торгах.
		/// </summary>
		public readonly PlazaColumn IsLimited;

		/// <summary>
		/// Верхний лимит цены.
		/// </summary>
		public readonly PlazaColumn LimitUp;

		/// <summary>
		/// Нижний лимит цены.
		/// </summary>
		public readonly PlazaColumn LimitDown;

		/// <summary>
		/// Скорректированная расчетная цена предыдущей сессии.
		/// </summary>
		public readonly PlazaColumn OldKotir;

		/// <summary>
		/// Код базового актива.
		/// </summary>
		public readonly PlazaColumn CodeVcb;

		/// <summary>
		/// Минимальный шаг цены.
		/// </summary>
		public readonly PlazaColumn MinStep;

		/// <summary>
		/// К-во единиц базового актива в инструменте.
		/// </summary>
		public readonly PlazaColumn LotVolume;

		/// <summary>
		/// Стоимость шага цены.
		/// </summary>
		public readonly PlazaColumn StepPrice;

		/// <summary>
		/// Дата окончания обращения инструмента.
		/// </summary>
		public readonly PlazaColumn DateEndTrade;

		/// <summary>
		/// Котировка после последнего клиринга.
		/// </summary>
		public readonly PlazaColumn LastClearingQuote;

		/// <summary>
		/// Поле признаков.
		/// </summary>
		public readonly PlazaColumn Signs;

		/// <summary>
		/// Количество знаков после запятой в цене
		/// </summary>
		public readonly PlazaColumn RoundTo;
	}
}