﻿namespace StockSharp.Plaza.Metadata
{
	using System;

	/// <summary>
	/// Поток FORTS_FUTINFO_REPL - Фьючерсы: справочная и сессионная информация
	/// Таблица fut_sess_contents: Cправочник торгуемых инструментов
	/// </summary>
	public class PlazaSessionContentsFutureColumns : PlazaSessionContentsDerivativeColumns
	{
		internal PlazaSessionContentsFutureColumns()
			: base(PlazaTableId.SessionContentsFuture)
		{
			InstTerm = new PlazaColumn(TableId, "inst_term", typeof(int));
			BuyDeposit = new PlazaColumn(TableId, "buy_deposit", "d16.2");
			SellDeposit = new PlazaColumn(TableId, "sell_deposit", "d16.2");
			IsSpread = new PlazaColumn(TableId, "is_spread", typeof(bool));
			Coeff = new PlazaColumn(TableId, "coeff", "d9.6");
			DateExpiration = new PlazaColumn(TableId, "d_exp", typeof(DateTime));
			IsPercent = new PlazaColumn(TableId, "is_percent", typeof(bool));
			PercentRate = new PlazaColumn(TableId, "percent_rate", "d6.2");
			IsTradeEvening = new PlazaColumn(TableId, "is_trade_evening", typeof(bool));
			Ticker = new PlazaColumn(TableId, "ticker", typeof(int));
			State = new PlazaColumn(TableId, "state", typeof(int));
			PriceDir = new PlazaColumn(TableId, "price_dir", typeof(bool));
			MultilegType = new PlazaColumn(TableId, "multileg_type", typeof(int));
			LegsQty = new PlazaColumn(TableId, "legs_qty", typeof(int));
			StepPriceClr = new PlazaColumn(TableId, "step_price_clr", "d16.5");
			StepPriceInterclr = new PlazaColumn(TableId, "step_price_interclr", "d16.5");
			StepPriceCurr = new PlazaColumn(TableId, "step_price_curr", "d16.5");
		}

		/// <summary>
		/// Смещение от спота
		/// </summary>
		public readonly PlazaColumn InstTerm;

		/// <summary>
		/// ГО покупателя
		/// </summary>
		public readonly PlazaColumn BuyDeposit;

		/// <summary>
		/// ГО продавца
		/// </summary>
		public readonly PlazaColumn SellDeposit;

		/// <summary>
		/// Признак вхождения фьючерса в межмесячный спрэд. 1 –
		/// входит; 0 – не входит
		/// </summary>
		public readonly PlazaColumn IsSpread;

		/// <summary>
		/// Коэффициент межмесячного спрэда
		/// </summary>
		public readonly PlazaColumn Coeff;

		/// <summary>
		/// Дата исполнения инструмента
		/// </summary>
		public readonly PlazaColumn DateExpiration;

		/// <summary>
		/// Признак того, что фьючерс торгуется в процентах. 1 -
		/// торгуется процентах, 0 – торгуется не в процентах
		/// </summary>
		public readonly PlazaColumn IsPercent;

		/// <summary>
		/// Процентная ставка для расчета вариационной маржи по процентным фьючерсам
		/// </summary>
		public readonly PlazaColumn PercentRate;

		/// <summary>
		/// Признак торговли в вечернюю сессию
		/// </summary>
		public readonly PlazaColumn IsTradeEvening;

		/// <summary>
		/// Уникальный числовой код Главного Спота
		/// </summary>
		public readonly PlazaColumn Ticker;

		/// <summary>
		/// Состояние торговли по инструменту
		/// </summary>
		public readonly PlazaColumn State;

		/// <summary>
		/// Направление цены инструмента
		/// </summary>
		public readonly PlazaColumn PriceDir;

		/// <summary>
		/// Тип связки
		/// </summary>
		public readonly PlazaColumn MultilegType;

		/// <summary>
		/// Количество инструментов в связке
		/// </summary>
		public readonly PlazaColumn LegsQty;

		/// <summary>
		/// Cтоимость шага цены вечернего клиринга
		/// </summary>
		public readonly PlazaColumn StepPriceClr;

		/// <summary>
		/// Cтоимость шага цены пром. клиринга
		/// </summary>
		public readonly PlazaColumn StepPriceInterclr;

		/// <summary>
		/// Стоимость минимального шага цены, выраженная в валюте
		/// </summary>
		public readonly PlazaColumn StepPriceCurr;
	}
}