﻿using System;

namespace StockSharp.Plaza.Metadata
{
	/// <summary>
	/// Поток FORTS_FUTINFO_REPL - Фьючерсы: справочная и сессионная информация.
	/// Таблица session: Информация о торговой сессии.
	/// </summary>
	public class PlazaSessionFutureColumns : PlazaColumns
	{
		internal PlazaSessionFutureColumns()
			: base(PlazaTableId.SessionFuture)
		{
			SessId = new PlazaColumn(TableId, "sess_id", typeof(int));
			BeginTime = new PlazaColumn(TableId, "begin", typeof(DateTime));
			EndTime = new PlazaColumn(TableId, "end", typeof(DateTime));
			State = new PlazaColumn(TableId, "state", typeof(int));
			OptSessId = new PlazaColumn(TableId, "opt_sess_id", typeof(int));
			InterClBeginTime = new PlazaColumn(TableId, "inter_cl_begin", typeof(DateTime));
			InterClEndTime = new PlazaColumn(TableId, "inter_cl_end", typeof(DateTime));
			InterClState = new PlazaColumn(TableId, "inter_cl_state", typeof(int));
			EveOn = new PlazaColumn(TableId, "eve_on", typeof(bool));
			EveBeginTime = new PlazaColumn(TableId, "eve_begin", typeof(DateTime));
			EveEndTime = new PlazaColumn(TableId, "eve_end", typeof(DateTime));
			MonOn = new PlazaColumn(TableId, "mon_on", typeof(bool));
			MonBeginTime = new PlazaColumn(TableId, "mon_begin", typeof(DateTime));
			MonEndTime = new PlazaColumn(TableId, "mon_end", typeof(DateTime));
			PosTransferBeginTime = new PlazaColumn(TableId, "pos_transfer_begin", typeof(DateTime));
			PosTransferEndTime = new PlazaColumn(TableId, "pos_transfer_end", typeof(DateTime));
		}

		/// <summary>
		/// Идентификатор торговой сессии.
		/// </summary>
		public readonly PlazaColumn SessId;

		/// <summary>
		/// Время начала.
		/// </summary>
		public readonly PlazaColumn BeginTime;

		/// <summary>
		/// Время окончания.
		/// </summary>
		public readonly PlazaColumn EndTime;

		/// <summary>
		/// Состояние сессии.
		/// </summary>
		public readonly PlazaColumn State;

		/// <summary>
		/// Номер соответствующей опционной сессии.
		/// </summary>
		public readonly PlazaColumn OptSessId;

		/// <summary>
		/// Время начала пром. клиринга.
		/// </summary>
		public readonly PlazaColumn InterClBeginTime;

		/// <summary>
		/// Время окончания пром. клиринга.
		/// </summary>
		public readonly PlazaColumn InterClEndTime;

		/// <summary>
		/// Состояние пром. клиринга.
		/// </summary>
		public readonly PlazaColumn InterClState;

		/// <summary>
		/// Признак того, что доп вечерняя сессия будет проводиться.
		/// </summary>
		public readonly PlazaColumn EveOn;

		/// <summary>
		/// Время начала доп. вечерней сессии.
		/// </summary>
		public readonly PlazaColumn EveBeginTime;

		/// <summary>
		/// Время окончания доп. вечерней сессии.
		/// </summary>
		public readonly PlazaColumn EveEndTime;

		/// <summary>
		/// Признак того, что доп утренняя сессия будет проводиться.
		/// </summary>
		public readonly PlazaColumn MonOn;

		/// <summary>
		/// Время начала доп. утренней сессии.
		/// </summary>
		public readonly PlazaColumn MonBeginTime;

		/// <summary>
		/// Время окончания доп. утренней сессии.
		/// </summary>
		public readonly PlazaColumn MonEndTime;

		/// <summary>
		/// Начало интервала переноса позиций.
		/// </summary>
		public readonly PlazaColumn PosTransferBeginTime;

		/// <summary>
		/// Конец интервала переноса позиций.
		/// </summary>
		public readonly PlazaColumn PosTransferEndTime;
	}
}