﻿namespace StockSharp.Plaza.Metadata
{
	using System;

	using Ecng.Common;
	using Ecng.Serialization;

	static class ReplicationSchemas
	{
		// схема по умолчанию
		public const string Current = "CustReplScheme";

		public const string Aggregation = "Aggr";
		public const string FutureCommon = "FutCommon";
		public const string FutureInfo = "FUTINFO";
		public const string FutureOrderBook = "FutOrderBook";
		public const string FutureTrade = "FutTrade";
		public const string FutureDeal = "FutUserDeal";
		public const string Info = "INFO";
		public const string Message = "message";
		public const string MiscInfo = "MiscInfo";
		public const string Money = "MoneyClr";
		public const string OptionCommon = "OptCommon";
		public const string OptionInfo = "OPTINFO";
		public const string OptionOrderBook = "OptOrderBook";
		public const string OptionTrade = "OptTrade";
		public const string OptionDeal = "OptUserDeal";
		public const string Portfolio = "PART";
		public const string Position = "POS";
		public const string Index = "RTSIndex";
		public const string Vm = "VM";
		public const string Volatility = "Volatility";
	}

	/// <summary>
	/// Таблица с метаданными.
	/// </summary>
	[EntityFactory(typeof(UnitializedEntityFactory<PlazaTable>))]
	[TypeSchemaFactory(SearchBy.Properties, VisibleScopes.Both)]
	public class PlazaTable : Equatable<PlazaTable>
	{
		internal PlazaTable(PlazaTableId id, string name)
		{
			if (id == null)
				throw new ArgumentNullException("id");

			if (name.IsEmpty())
				throw new ArgumentException("name");

			Id = id;
			//SystemName = systemName;
			//ReplicationStream = replicationStream;
			Name = name;
			//UniqueName = ReplicationStream + "\\" + SystemName;
			ReplicationScheme = ReplicationSchemas.Current;
			Columns = new PlazaColumnList { Table = this };
		}

		internal PlazaTableId Id { get; private set; }

		//// Это свойство нужно, потому что названия таблиц могут повторяться
		//// Например, у всех 6 стаканов разные названия потоков (FORTS_FUTAGGR50_REPL, FORTS_OPTAGGR20_REPL и т.д.) 
		//// и одно название таблицы: orders_aggr
		//internal string UniqueName { get; private set; }

		///// <summary>
		///// Название таблицы в Plaza.
		///// </summary>
		//public string SystemName { get; private set; }

		///// <summary>
		///// Поток репликации Plaza.
		///// </summary>
		//internal string ReplicationStream { get; private set; }

		/// <summary>
		/// Схема репликации Plaza.
		/// </summary>
		internal string ReplicationScheme { get; private set; }

		/// <summary>
		/// Название таблицы.
		/// </summary>
		public string Name { get; private set; }

		/// <summary>
		/// Рассчитать хэш-код.
		/// </summary>
		/// <returns>Хэш-код.</returns>
		public override int GetHashCode()
		{
			return Id.GetHashCode();
		}

		/// <summary>
		/// Определяет, равен ли заданный объект <see cref="PlazaTable"/> текущему объекту <see cref="PlazaTable"/>.
		/// </summary>
		/// <param name="other">Объект <see cref="PlazaTable"/>, который требуется сравнить с текущим объектом <see cref="PlazaTable"/>.</param>
		/// <returns>Значение true, если указанный объект <paramref name="other"/> равен текущему объекту <see cref="PlazaTable"/>; в противном случае — значение false.</returns>
		protected override bool OnEquals(PlazaTable other)
		{
			return Id == other.Id && ReplicationScheme == other.ReplicationScheme;
		}

		/// <summary>
		/// Создать копию таблицы.
		/// </summary>
		/// <returns>Копия таблицы.</returns>
		public override PlazaTable Clone()
		{
			throw new NotSupportedException();
		}

		/// <summary>
		/// Список колонок, которые необходимо передать с сервера Plaza.
		/// </summary>
		public PlazaColumnList Columns { get; private set; }

		///// <summary>
		///// Сохранить настройки таблицы в файл.
		///// </summary>
		//public void Save()
		//{
		//    Save(GetDefaultFileName());
		//}

		///// <summary>
		///// Сохранить настройки таблицы в файл.
		///// </summary>
		///// <param name="fileName">Имя файла.</param>
		//public void Save(string fileName)
		//{
		//    new XmlSerializer<PlazaTable>().Serialize(this, fileName);
		//}

		///// <summary>
		///// Загрузить настройки таблицы из файла.
		///// </summary>
		//public void Load()
		//{
		//    Load(GetDefaultFileName());
		//}

		///// <summary>
		///// Загрузить настройки таблицы из файла.
		///// </summary>
		///// <param name="fileName">Имя файла.</param>
		//public void Load(string fileName)
		//{
		//    var clone = new XmlSerializer<PlazaTable>().Deserialize(fileName);
		//    Columns = new PlazaColumnList { Table = this };
		//    Columns.AddRange(clone.Columns);
		//}

		//private string GetDefaultFileName()
		//{
		//    return "Plaza{0}Table.xml".Put(SystemName);
		//}
	}
}