﻿namespace StockSharp.Plaza
{
	/// <summary>
	/// Состояния торговой сессии.
	/// </summary>
	public enum SessionState
	{
		/// <summary>
		/// Сессия назначена. Нельзя ставить заявки, но можно удалять.
		/// </summary>
		Assigned,

		/// <summary>
		/// Сессия идет. Можно ставить и удалять заявки.
		/// </summary>
		Active,

		/// <summary>
		/// Приостановка торгов по всем инструментам. Нельзя ставить заявки, но можно удалять.
		/// </summary>
		Paused,

		/// <summary>
		/// Сессия принудительно завершена. Нельзя ставить и удалять заявки.
		/// </summary>
		ForceStopped,

		/// <summary>
		/// Сессия завершена по времени. Нельзя ставить и удалять заявки.
		/// </summary>
		Ended,
	}

    /// <summary>
    /// Состояние торговли по инструменту.
    /// </summary>
    public enum SecurityState
    {
        /// <summary>
        /// Сессия по этому инструменту назначена. Нельзя ставить заявки, но можно удалять по этому инструменту.
        /// </summary>
        Assigned,

        /// <summary>
        /// Сессия по этому инструменту идет. Можно ставить и удалять заявки по этому инструменту.
        /// </summary>
        Active,

        /// <summary>
        /// Приостановка торгов по всем инструментам. Нельзя ставить заявки, но можно удалять.
        /// </summary>
        AllPaused,

        /// <summary>
        /// Сессия по этому инструменту принудительно завершена. Нельзя ставить и удалять заявки по этому инструменту.
        /// </summary>
        ForceStopped,

        /// <summary>
        /// Сессия по этому инструменту завершена по времени. Нельзя ставить и удалять заявки по этому инструменту.
        /// </summary>
        Ended,

        /// <summary>
        /// Приостановка торгов по этому инструменту. Нельзя ставить заявки, но можно удалять по этому инструменту.
        /// </summary>
        Paused,
    }
}