namespace StockSharp.Plaza.Wrappers
{
	using System;

	using Ecng.Common;

	/// <summary>
	///  .
	/// </summary>
	[Flags]
	public enum ConnectionWrapperStatus
	{
		/// <summary>
		///      .
		/// </summary>
		Disconnected = 1,

		/// <summary>
		///    .
		/// </summary>
		Connected = 2,

		/// <summary>
		///    ,        . 
		/// </summary>
		Invalid = 4,

		/// <summary>
		///      .
		/// </summary>
		Busy = 8,

		/// <summary>
		///  ,     .
		/// </summary>
		RouterDisconnected = 65536,

		/// <summary>
		///     (  ),    ,        .
		/// </summary>
		RouterReconnecting = 131072,

		/// <summary>
		///        ,   .
		/// </summary>
		RouterConnected = 262144,

		/// <summary>
		///         . 
		/// </summary>
		RouterLoginFailed = 524288,

		/// <summary>
		///            ,    .
		/// </summary>
		RouterNoConnect = 1048576,
	}

	/// <summary>
	///     ,      .
	/// </summary>
	interface IConnectionWrapper
	{
		/// <summary>
		/// IP-   UNC-.
		/// </summary>
		string Host { get; set; }

		/// <summary>
		///   TCP/IP.
		/// </summary>
		uint Port { get; set; }

		/// <summary>
		///  ,     .
		/// </summary>
		string AppName { get; set; }

		/// <summary>
		///    .
		/// </summary>
		string Password { set; }

		/// <summary>
		///    .
		/// </summary>
		string LoginStr { get; set; }

		/// <summary>
		/// C   .
		/// </summary>
		ConnectionWrapperStatus Status { get; }

		/// <summary>
		///     .
		/// </summary>
		void Logout();

		/// <summary>
		///   .
		/// </summary>
		void Disconnect();

		/// <summary>
		///     .
		/// </summary>
		void Login();

		/// <summary>
		///      .
		/// </summary>
		/// <returns></returns>
		long Connect();

		/// <summary>
		///      .
		/// </summary>
		/// <param name="connStr">   .</param>
		/// <returns></returns>
		long Connect(string connStr);

		/// <summary>
		///       ,   .
		/// </summary>
		/// <param name="service"> .</param>
		/// <returns></returns>
		string ResolveService(string service);

		/// <summary>
		///    ,     .
		/// </summary>
		/// <param name="pollTimeout"></param>
		void ProcessMessage(TimeSpan pollTimeout);

		/// <summary>
		///       .
		/// </summary>
		event Action<IConnectionWrapper, ConnectionWrapperStatus> ConnectionStatusChanged;
	}

	class ConnectionWrapper32 : IConnectionWrapper
	{
		internal readonly P2ClientGateMTA32.CP2ConnectionClass Connection;

		public ConnectionWrapper32()
		{
			Connection = new P2ClientGateMTA32.CP2ConnectionClass();
			Connection.ConnectionStatusChanged += (a, b) => OnConnectionStatusChanged((ConnectionWrapperStatus)b);
		}

		public void Login()
		{
			Connection.Login();
		}

		public long Connect()
		{
			return Connection.Connect();
		}

		public void Logout()
		{
			Connection.Logout();
		}

		public void Disconnect()
		{
			Connection.Disconnect();
		}

		public string ResolveService(string service)
		{
			return Connection.ResolveService(service);
		}

		public void ProcessMessage(TimeSpan pollTimeout)
		{
			uint cookie;
			Connection.ProcessMessage(out cookie, (uint)pollTimeout.TotalMilliseconds);
		}

		public ConnectionWrapperStatus Status
		{
			get { return (ConnectionWrapperStatus)Connection.Status; }
		}

		public long Connect(string connStr)
		{
			return Connection.Connect2(connStr);
		}

		public string Host
		{
			get { return Connection.Host; }
			set { Connection.Host = value; }
		}

		public uint Port
		{
			get { return Connection.Port; }
			set { Connection.Port = value; }
		}

		public string AppName
		{
			get { return Connection.AppName; }
			set { Connection.AppName = value; }
		}

		public string Password
		{
			set { Connection.Password = value; }
		}

		public string LoginStr
		{
			get { return Connection.LoginStr; }
			set { Connection.LoginStr = value; }
		}

		public event Action<IConnectionWrapper, ConnectionWrapperStatus> ConnectionStatusChanged;

		public void OnConnectionStatusChanged(ConnectionWrapperStatus wrapperStatus)
		{
			ConnectionStatusChanged.SafeInvoke(this, wrapperStatus);
		}
	}

	class ConnectionWrapper64 : IConnectionWrapper
	{
		internal readonly P2ClientGateMTA64.CP2ConnectionClass Connection;

		public ConnectionWrapper64()
		{
			Connection = new P2ClientGateMTA64.CP2ConnectionClass();
			Connection.ConnectionStatusChanged += (a, b) => OnConnectionStatusChanged((ConnectionWrapperStatus)b);
		}

		public void Login()
		{
			Connection.Login();
		}

		public Int64 Connect()
		{
			return Connection.Connect();
		}

		public void Logout()
		{
			Connection.Logout();
		}

		public void Disconnect()
		{
			Connection.Disconnect();
		}

		public string ResolveService(string service)
		{
			return Connection.ResolveService(service);
		}

		public void ProcessMessage(TimeSpan pollTimeout)
		{
			uint cookie;
			Connection.ProcessMessage(out cookie, (uint)pollTimeout.TotalMilliseconds);
		}

		public ConnectionWrapperStatus Status
		{
			get { return (ConnectionWrapperStatus)Connection.Status; }
		}

		public long Connect(string connStr)
		{
			return Connection.Connect2(connStr);
		}

		public string Host
		{
			get { return Connection.Host; }
			set { Connection.Host = value; }
		}

		public uint Port
		{
			get { return Connection.Port; }
			set { Connection.Port = value; }
		}

		public string AppName
		{
			get { return Connection.AppName; }
			set { Connection.AppName = value; }
		}

		public string Password
		{
			set { Connection.Password = value; }
		}

		public string LoginStr
		{
			get { return Connection.LoginStr; }
			set { Connection.LoginStr = value; }
		}

		public event Action<IConnectionWrapper, ConnectionWrapperStatus> ConnectionStatusChanged;

		public void OnConnectionStatusChanged(ConnectionWrapperStatus wrapperStatus)
		{
			ConnectionStatusChanged.SafeInvoke(this, wrapperStatus);
		}
	}
}