namespace StockSharp.Plaza.Wrappers
{
	using System;

	/// <summary>
	///   .
	/// </summary>
	public enum StreamWrapperRequests
	{
		/// <summary>
		///          .
		/// </summary>
		Local = 0,

		/// <summary>
		///           .        .
		/// </summary>
		CombinedSnapshot = 1,

		/// <summary>
		///           .           -.
		/// </summary>
		CombinedDynamic = 2,

		/// <summary>
		///        .    ,     .
		/// </summary>
		RemoteSnapshot = 3,

		/// <summary>
		///       .
		/// </summary>
		RemoteOnline = 8,

		/// <summary>
		/// ,       , ,  .
		/// </summary>
		RemoveDeleted = 4,
	}

	/// <summary>
	///   .
	/// </summary>
	public enum StreamWrapperStates
	{
		/// <summary>
		///  .
		/// </summary>
		Closed = 0,

		/// <summary>
		///          .
		/// </summary>
		LocalSnapshot = 1,

		/// <summary>
		///        .
		/// </summary>
		RemoveSnapshot = 2,

		/// <summary>
		///     -   .
		/// </summary>
		Online = 3,

		/// <summary>
		///       .
		/// </summary>
		Complete = 4,

		/// <summary>
		///         . 
		/// </summary>
		ReOpenned = 5,

		/// <summary>
		/// .
		/// </summary>
		Error = 6,
	}

	/// <summary>
	///   .
	/// </summary>
	interface IStreamWrapper
	{
		/// <summary>
		///  .
		/// </summary>
		void Close();

		/// <summary>
		///    .
		/// </summary>
		/// <param name="conn">   .</param>
		void Open(IConnectionWrapper conn);

		/// <summary>
		///    .
		/// </summary>
		string ConnectionString { get; set; }

		/// <summary>
		///   .
		/// </summary>
		StreamWrapperRequests Type { get; set; }

		/// <summary>
		///   .
		/// </summary>
		string StreamName { get; set; }

		/// <summary>
		///   .
		/// </summary>
		StreamWrapperStates State { get; }

		/// <summary>
		///     . 
		/// </summary>
		ITableSetWrapper TableSet { get; set; }

		/// <summary>
		///          .
		/// </summary>
		event Action<IStreamWrapper> StreamDataBegin;

		/// <summary>
		///          .
		/// </summary>
		event Action<IStreamWrapper> StreamDataEnd;

		/// <summary>
		///            .
		/// </summary>
		event Action<IStreamWrapper, string, long> StreamDatumDeleted;

		/// <summary>
		///      .
		/// </summary>
		event Action<IStreamWrapper, string, long, IRecordWrapper> StreamDataDeleted;

		/// <summary>
		///       .
		/// </summary>
		event Action<IStreamWrapper, StreamWrapperStates> StreamStateChanged;

		/// <summary>
		///      .
		/// </summary>
		event Action<IStreamWrapper, string, IRecordWrapper> StreamDataInserted;

		/// <summary>
		///      .     Update  .
		/// </summary>
		event Action<IStreamWrapper, string, long, IRecordWrapper> StreamDataUpdated;

		/// <summary>
		///        .
		/// </summary>
		event Action<IStreamWrapper, int> StreamLifeNumChanged;
	}

	class StreamWrapper32 : IStreamWrapper
	{
		private readonly P2ClientGateMTA32.CP2DataStream _stream;

		public StreamWrapper32()
		{
			_stream = new P2ClientGateMTA32.CP2DataStream();

			_stream.StreamDataBegin += a => StreamDataBegin(this);
			_stream.StreamDataEnd += a => StreamDataEnd(this);
			_stream.StreamDatumDeleted += (a, b, c) => StreamDatumDeleted(this, b, c);
			_stream.StreamDataDeleted += (a, b, c, d) => StreamDataDeleted(this, b, c, new RecordWrapper32(d));
			_stream.StreamStateChanged += (a, b) => StreamStateChanged(this, (StreamWrapperStates)b);
			_stream.StreamDataInserted += (a, b, c) => StreamDataInserted(this, b, new RecordWrapper32(c));
			_stream.StreamDataUpdated += (a, b, c, d) => StreamDataUpdated(this, b, c, new RecordWrapper32(d));
			_stream.StreamLifeNumChanged += (a, b) => StreamLifeNumChanged(this, b);
		}

		public void Close()
		{
			_stream.Close();
		}

		public void Open(IConnectionWrapper conn)
		{
			var c = (ConnectionWrapper32)conn;
			_stream.Open(c.Connection);
		}

		public string ConnectionString
		{
			get { return _stream.DBConnString; }
			set { _stream.DBConnString = value; }
		}

		public StreamWrapperRequests Type
		{
			get { return (StreamWrapperRequests)_stream.type; }
			set { _stream.type = (P2ClientGateMTA32.TRequestType)value; }
		}

		public string StreamName
		{
			get { return _stream.StreamName; }
			set { _stream.StreamName = value; }
		}

		public StreamWrapperStates State
		{
			get { return (StreamWrapperStates)_stream.State; }
		}

		private ITableSetWrapper _tableSet;

		public ITableSetWrapper TableSet
		{
			get { return _tableSet; }
			set
			{
				_tableSet = value;
				_stream.TableSet = ((TableSetWrapper32)value).TableSet;
			}
		}

		public event Action<IStreamWrapper> StreamDataBegin;
		public event Action<IStreamWrapper> StreamDataEnd;
		public event Action<IStreamWrapper, string, long> StreamDatumDeleted;
		public event Action<IStreamWrapper, string, long, IRecordWrapper> StreamDataDeleted;
		public event Action<IStreamWrapper, StreamWrapperStates> StreamStateChanged;
		public event Action<IStreamWrapper, string, IRecordWrapper> StreamDataInserted;
		public event Action<IStreamWrapper, string, long, IRecordWrapper> StreamDataUpdated;
		public event Action<IStreamWrapper, int> StreamLifeNumChanged;
	}

	class StreamWrapper64 : IStreamWrapper
	{
		private readonly P2ClientGateMTA64.CP2DataStream _stream;

		public StreamWrapper64()
		{
			_stream = new P2ClientGateMTA64.CP2DataStream();

			_stream.StreamDataBegin += a => StreamDataBegin(this);
			_stream.StreamDataEnd += a => StreamDataEnd(this);
			_stream.StreamDatumDeleted += (a, b, c) => StreamDatumDeleted(this, b, c);
			_stream.StreamDataDeleted += (a, b, c, d) => StreamDataDeleted(this, b, c, new RecordWrapper64(d));
			_stream.StreamStateChanged += (a, b) => StreamStateChanged(this, (StreamWrapperStates)b);
			_stream.StreamDataInserted += (a, b, c) => StreamDataInserted(this, b, new RecordWrapper64(c));
			_stream.StreamDataUpdated += (a, b, c, d) => StreamDataUpdated(this, b, c, new RecordWrapper64(d));
			_stream.StreamLifeNumChanged += (a, b) => StreamLifeNumChanged(this, b);
		}

		public void Close()
		{
			_stream.Close();
		}

		public void Open(IConnectionWrapper conn)
		{
			var c = (ConnectionWrapper64)conn;
			_stream.Open(c.Connection);
		}

		public string ConnectionString
		{
			get { return _stream.DBConnString; }
			set { _stream.DBConnString = value; }
		}

		public StreamWrapperRequests Type
		{
			get { return (StreamWrapperRequests)_stream.type; }
			set { _stream.type = (P2ClientGateMTA64.TRequestType)value; }
		}

		public string StreamName
		{
			get { return _stream.StreamName; }
			set { _stream.StreamName = value; }
		}

		public StreamWrapperStates State
		{
			get { return (StreamWrapperStates)_stream.State; }
		}

		private ITableSetWrapper _tableSet;

		public ITableSetWrapper TableSet
		{
			get { return _tableSet; }
			set
			{
				_tableSet = value;
				_stream.TableSet = ((TableSetWrapper64)value).TableSet;
			}
		}

		public event Action<IStreamWrapper> StreamDataBegin;
		public event Action<IStreamWrapper> StreamDataEnd;
		public event Action<IStreamWrapper, string, long> StreamDatumDeleted;
		public event Action<IStreamWrapper, string, long, IRecordWrapper> StreamDataDeleted;
		public event Action<IStreamWrapper, StreamWrapperStates> StreamStateChanged;
		public event Action<IStreamWrapper, string, IRecordWrapper> StreamDataInserted;
		public event Action<IStreamWrapper, string, long, IRecordWrapper> StreamDataUpdated;
		public event Action<IStreamWrapper, int> StreamLifeNumChanged;
	}
}